// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: google/api/launch_stage.proto
// Protobuf C++ Version: 7.34.1

#ifndef google_2fapi_2flaunch_5fstage_2eproto_2epb_2eh
#define google_2fapi_2flaunch_5fstage_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7034001
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/generated_enum_reflection.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_google_2fapi_2flaunch_5fstage_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_google_2fapi_2flaunch_5fstage_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_google_2fapi_2flaunch_5fstage_2eproto;
}  // extern "C"
namespace google {
namespace api {
enum LaunchStage : int;
extern const uint32_t LaunchStage_internal_data_[];
}  // namespace api
namespace protobuf {
template <>
internal::EnumTraitsT<::google::api::LaunchStage_internal_data_>
    internal::EnumTraitsImpl::value<::google::api::LaunchStage>;
}  // namespace protobuf
}  // namespace google

namespace google {
namespace api {
enum LaunchStage : int {
  LAUNCH_STAGE_UNSPECIFIED = 0,
  UNIMPLEMENTED = 6,
  PRELAUNCH = 7,
  EARLY_ACCESS = 1,
  ALPHA = 2,
  BETA = 3,
  GA = 4,
  DEPRECATED = 5,
  LaunchStage_INT_MIN_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::min(),
  LaunchStage_INT_MAX_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::max(),
};

extern const uint32_t LaunchStage_internal_data_[];
inline constexpr LaunchStage LaunchStage_MIN =
    static_cast<LaunchStage>(0);
inline constexpr LaunchStage LaunchStage_MAX =
    static_cast<LaunchStage>(7);
[[nodiscard]] inline bool LaunchStage_IsValid(int value) {
  return 0 <= value && value <= 7;
}
inline constexpr int LaunchStage_ARRAYSIZE = 7 + 1;
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
LaunchStage_descriptor();
[[nodiscard]] inline auto ProtobufInternalGetEnumDescriptor(LaunchStage) {
  return LaunchStage_descriptor();
}
template <typename T>
[[nodiscard]] const ::std::string& LaunchStage_Name(T value) {
  static_assert(::std::is_same<T, LaunchStage>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to LaunchStage_Name().");
  return LaunchStage_Name(static_cast<LaunchStage>(value));
}
template <>
[[nodiscard]] inline const ::std::string& LaunchStage_Name(LaunchStage value) {
  return ::google::protobuf::internal::NameOfDenseEnum<LaunchStage_descriptor, 0, 7>(
      static_cast<int>(value));
}
[[nodiscard]] inline bool LaunchStage_Parse(
    ::absl::string_view name, LaunchStage* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<LaunchStage>(LaunchStage_descriptor(), name,
                                           value);
}

// ===================================================================



// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace api
}  // namespace google


namespace google {
namespace protobuf {

template <>
struct is_proto_enum<::google::api::LaunchStage> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::google::api::LaunchStage>() {
  return ::google::api::LaunchStage_descriptor();
}

}  // namespace protobuf
}  // namespace google

// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // google_2fapi_2flaunch_5fstage_2eproto_2epb_2eh
