// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: google/cloud/bigquery/storage/v1/protobuf.proto
// Protobuf C++ Version: 7.34.1

#ifndef google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto_2epb_2eh
#define google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7034001
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/unknown_field_set.h"
#include "google/protobuf/descriptor.pb.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto;
}  // extern "C"
namespace google {
namespace cloud {
namespace bigquery {
namespace storage {
namespace v1 {
class ProtoRows;
struct ProtoRowsDefaultTypeInternal;
extern ProtoRowsDefaultTypeInternal _ProtoRows_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull ProtoRows_class_data_;
class ProtoSchema;
struct ProtoSchemaDefaultTypeInternal;
extern ProtoSchemaDefaultTypeInternal _ProtoSchema_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull ProtoSchema_class_data_;
}  // namespace v1
}  // namespace storage
}  // namespace bigquery
}  // namespace cloud
namespace protobuf {
}  // namespace protobuf
}  // namespace google

namespace google {
namespace cloud {
namespace bigquery {
namespace storage {
namespace v1 {

// ===================================================================


// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED ProtoRows final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:google.cloud.bigquery.storage.v1.ProtoRows) */ {
 public:
  inline ProtoRows() : ProtoRows(nullptr) {}
  ~ProtoRows() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(ProtoRows* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(ProtoRows));
  }
#endif

  template <typename = void>
  explicit constexpr ProtoRows(::google::protobuf::internal::ConstantInitialized);

  inline ProtoRows(const ProtoRows& from) : ProtoRows(nullptr, from) {}
  inline ProtoRows(ProtoRows&& from) noexcept
      : ProtoRows(nullptr, ::std::move(from)) {}
  inline ProtoRows& operator=(const ProtoRows& from) {
    CopyFrom(from);
    return *this;
  }
  inline ProtoRows& operator=(ProtoRows&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const ProtoRows& default_instance() {
    return *reinterpret_cast<const ProtoRows*>(
        &_ProtoRows_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(ProtoRows& a, ProtoRows& b) { a.Swap(&b); }
  inline void Swap(ProtoRows* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ProtoRows* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] ProtoRows* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<ProtoRows>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const ProtoRows& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const ProtoRows& from) { ProtoRows::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(ProtoRows* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "google.cloud.bigquery.storage.v1.ProtoRows"; }

  explicit ProtoRows(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  ProtoRows(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const ProtoRows& from);
  ProtoRows(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, ProtoRows&& from) noexcept
      : ProtoRows(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kSerializedRowsFieldNumber = 1,
  };
  // repeated bytes serialized_rows = 1;
  [[nodiscard]] int serialized_rows_size()
      const;
  private:
  int _internal_serialized_rows_size() const;

  public:
  void clear_serialized_rows() ;
  [[nodiscard]] const ::std::string& serialized_rows(int index) const;
  ::std::string* PROTOBUF_NONNULL mutable_serialized_rows(int index);
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_serialized_rows(int index, Arg_&& value, Args_... args);
  ::std::string* PROTOBUF_NONNULL add_serialized_rows();
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void add_serialized_rows(Arg_&& value, Args_... args);
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::std::string>&
  serialized_rows() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL
  mutable_serialized_rows();

  private:
  const ::google::protobuf::RepeatedPtrField<::std::string>& _internal_serialized_rows() const;
  ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL _internal_mutable_serialized_rows();

  public:
  // @@protoc_insertion_point(class_scope:google.cloud.bigquery.storage.v1.ProtoRows)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<0, 1,
                                   0, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const ProtoRows& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField<::std::string> serialized_rows_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull ProtoRows_class_data_;
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED ProtoSchema final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:google.cloud.bigquery.storage.v1.ProtoSchema) */ {
 public:
  inline ProtoSchema() : ProtoSchema(nullptr) {}
  ~ProtoSchema() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(ProtoSchema* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(ProtoSchema));
  }
#endif

  template <typename = void>
  explicit constexpr ProtoSchema(::google::protobuf::internal::ConstantInitialized);

  inline ProtoSchema(const ProtoSchema& from) : ProtoSchema(nullptr, from) {}
  inline ProtoSchema(ProtoSchema&& from) noexcept
      : ProtoSchema(nullptr, ::std::move(from)) {}
  inline ProtoSchema& operator=(const ProtoSchema& from) {
    CopyFrom(from);
    return *this;
  }
  inline ProtoSchema& operator=(ProtoSchema&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const ProtoSchema& default_instance() {
    return *reinterpret_cast<const ProtoSchema*>(
        &_ProtoSchema_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(ProtoSchema& a, ProtoSchema& b) { a.Swap(&b); }
  inline void Swap(ProtoSchema* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ProtoSchema* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] ProtoSchema* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<ProtoSchema>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const ProtoSchema& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const ProtoSchema& from) { ProtoSchema::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return IsInitializedImpl(*this);
  }

  private:
  static bool IsInitializedImpl(const MessageLite& msg);

  public:
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(ProtoSchema* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "google.cloud.bigquery.storage.v1.ProtoSchema"; }

  explicit ProtoSchema(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  ProtoSchema(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const ProtoSchema& from);
  ProtoSchema(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, ProtoSchema&& from) noexcept
      : ProtoSchema(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kProtoDescriptorFieldNumber = 1,
  };
  // .google.protobuf.DescriptorProto proto_descriptor = 1;
  [[nodiscard]] bool has_proto_descriptor()
      const;
  void clear_proto_descriptor() ;
  [[nodiscard]] const ::google::protobuf::DescriptorProto& proto_descriptor() const;
  [[nodiscard]] ::google::protobuf::DescriptorProto* PROTOBUF_NULLABLE release_proto_descriptor();
  ::google::protobuf::DescriptorProto* PROTOBUF_NONNULL mutable_proto_descriptor();
  void set_allocated_proto_descriptor(::google::protobuf::DescriptorProto* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_proto_descriptor(::google::protobuf::DescriptorProto* PROTOBUF_NULLABLE value);
  ::google::protobuf::DescriptorProto* PROTOBUF_NULLABLE unsafe_arena_release_proto_descriptor();

  private:
  const ::google::protobuf::DescriptorProto& _internal_proto_descriptor() const;
  ::google::protobuf::DescriptorProto* PROTOBUF_NONNULL _internal_mutable_proto_descriptor();

  public:
  // @@protoc_insertion_point(class_scope:google.cloud.bigquery.storage.v1.ProtoSchema)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<0, 1,
                                   1, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const ProtoSchema& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::DescriptorProto* PROTOBUF_NULLABLE proto_descriptor_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull ProtoSchema_class_data_;

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// ProtoSchema

// .google.protobuf.DescriptorProto proto_descriptor = 1;
inline bool ProtoSchema::has_proto_descriptor() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000001U);
  PROTOBUF_ASSUME(!value || _impl_.proto_descriptor_ != nullptr);
  return value;
}
inline const ::google::protobuf::DescriptorProto& ProtoSchema::_internal_proto_descriptor() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::google::protobuf::DescriptorProto* p = _impl_.proto_descriptor_;
  return p != nullptr ? *p : reinterpret_cast<const ::google::protobuf::DescriptorProto&>(::google::protobuf::_DescriptorProto_default_instance_);
}
inline const ::google::protobuf::DescriptorProto& ProtoSchema::proto_descriptor() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:google.cloud.bigquery.storage.v1.ProtoSchema.proto_descriptor)
  return _internal_proto_descriptor();
}
inline void ProtoSchema::unsafe_arena_set_allocated_proto_descriptor(
    ::google::protobuf::DescriptorProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.proto_descriptor_);
  }
  _impl_.proto_descriptor_ = reinterpret_cast<::google::protobuf::DescriptorProto*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:google.cloud.bigquery.storage.v1.ProtoSchema.proto_descriptor)
}
inline ::google::protobuf::DescriptorProto* PROTOBUF_NULLABLE ProtoSchema::release_proto_descriptor() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::google::protobuf::DescriptorProto* released = _impl_.proto_descriptor_;
  _impl_.proto_descriptor_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::google::protobuf::DescriptorProto* PROTOBUF_NULLABLE ProtoSchema::unsafe_arena_release_proto_descriptor() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:google.cloud.bigquery.storage.v1.ProtoSchema.proto_descriptor)

  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::google::protobuf::DescriptorProto* temp = _impl_.proto_descriptor_;
  _impl_.proto_descriptor_ = nullptr;
  return temp;
}
inline ::google::protobuf::DescriptorProto* PROTOBUF_NONNULL ProtoSchema::_internal_mutable_proto_descriptor() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.proto_descriptor_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::google::protobuf::DescriptorProto>(GetArena());
    _impl_.proto_descriptor_ = reinterpret_cast<::google::protobuf::DescriptorProto*>(p);
  }
  return _impl_.proto_descriptor_;
}
inline ::google::protobuf::DescriptorProto* PROTOBUF_NONNULL ProtoSchema::mutable_proto_descriptor()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::google::protobuf::DescriptorProto* _msg = _internal_mutable_proto_descriptor();
  // @@protoc_insertion_point(field_mutable:google.cloud.bigquery.storage.v1.ProtoSchema.proto_descriptor)
  return _msg;
}
inline void ProtoSchema::set_allocated_proto_descriptor(::google::protobuf::DescriptorProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.proto_descriptor_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(value)->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }

  _impl_.proto_descriptor_ = reinterpret_cast<::google::protobuf::DescriptorProto*>(value);
  // @@protoc_insertion_point(field_set_allocated:google.cloud.bigquery.storage.v1.ProtoSchema.proto_descriptor)
}

// -------------------------------------------------------------------

// ProtoRows

// repeated bytes serialized_rows = 1;
inline int ProtoRows::_internal_serialized_rows_size() const {
  return _internal_serialized_rows().size();
}
inline int ProtoRows::serialized_rows_size() const {
  return _internal_serialized_rows_size();
}
inline void ProtoRows::clear_serialized_rows() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.serialized_rows_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000001U);
}
inline ::std::string* PROTOBUF_NONNULL ProtoRows::add_serialized_rows()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::std::string* _s =
      _internal_mutable_serialized_rows()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add_mutable:google.cloud.bigquery.storage.v1.ProtoRows.serialized_rows)
  return _s;
}
inline const ::std::string& ProtoRows::serialized_rows(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:google.cloud.bigquery.storage.v1.ProtoRows.serialized_rows)
  return _internal_serialized_rows().Get(index);
}
inline ::std::string* PROTOBUF_NONNULL ProtoRows::mutable_serialized_rows(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:google.cloud.bigquery.storage.v1.ProtoRows.serialized_rows)
  return _internal_mutable_serialized_rows()->Mutable(index);
}
template <typename Arg_, typename... Args_>
inline void ProtoRows::set_serialized_rows(int index, Arg_&& value, Args_... args) {
  ::google::protobuf::internal::AssignToString(*_internal_mutable_serialized_rows()->Mutable(index), ::std::forward<Arg_>(value),
                        args... , ::google::protobuf::internal::BytesTag{});
  // @@protoc_insertion_point(field_set:google.cloud.bigquery.storage.v1.ProtoRows.serialized_rows)
}
template <typename Arg_, typename... Args_>
inline void ProtoRows::add_serialized_rows(Arg_&& value, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::google::protobuf::internal::AddToRepeatedPtrField(
      ::google::protobuf::MessageLite::internal_visibility(), GetArena(),
      *_internal_mutable_serialized_rows(), ::std::forward<Arg_>(value),
      args... , ::google::protobuf::internal::BytesTag{});
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:google.cloud.bigquery.storage.v1.ProtoRows.serialized_rows)
}
inline const ::google::protobuf::RepeatedPtrField<::std::string>& ProtoRows::serialized_rows()
    const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:google.cloud.bigquery.storage.v1.ProtoRows.serialized_rows)
  return _internal_serialized_rows();
}
inline ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL
ProtoRows::mutable_serialized_rows() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:google.cloud.bigquery.storage.v1.ProtoRows.serialized_rows)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_serialized_rows();
}
inline const ::google::protobuf::RepeatedPtrField<::std::string>&
ProtoRows::_internal_serialized_rows() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.serialized_rows_;
}
inline ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL
ProtoRows::_internal_mutable_serialized_rows() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.serialized_rows_;
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace v1
}  // namespace storage
}  // namespace bigquery
}  // namespace cloud
}  // namespace google


// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // google_2fcloud_2fbigquery_2fstorage_2fv1_2fprotobuf_2eproto_2epb_2eh
